@@ -24,96 +24,44 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-iot-lambda-dynamodb`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.iotlambdadynamodb`|
 
-## Overview
-
 This AWS Solutions Construct implements an AWS IoT topic rule, an AWS Lambda function and Amazon DynamoDB table with the least privileged permissions.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
-Typescript
+```javascript
+const { IotToLambdaToDynamoDBProps,  IotToLambdaToDynamoDB } from '@aws-solutions-constructs/aws-iot-lambda-dynamodb';
 
-```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
-import { IotToLambdaToDynamoDBProps, IotToLambdaToDynamoDB } from '@aws-solutions-constructs/aws-iot-lambda-dynamodb';
-import * as lambda from 'aws-cdk-lib/aws-lambda';
-
-const constructProps: IotToLambdaToDynamoDBProps = {
-  lambdaFunctionProps: {
-      code: lambda.Code.fromAsset(`lambda`),
-      runtime: lambda.Runtime.NODEJS_14_X,
-      handler: 'index.handler'
-  },
-  iotTopicRuleProps: {
-      topicRulePayload: {
-          ruleDisabled: false,
-          description: "Processing of DTC messages from the AWS Connected Vehicle Solution.",
-          sql: "SELECT * FROM 'connectedcar/dtc/#'",
-          actions: []
-      }
-  }
+const props: IotToLambdaToDynamoDBProps = {
+    lambdaFunctionProps: {
+        code: lambda.Code.fromAsset(`${__dirname}/lambda`),
+        runtime: lambda.Runtime.NODEJS_14_X,
+        handler: 'index.handler'
+    },
+    iotTopicRuleProps: {
+        topicRulePayload: {
+            ruleDisabled: false,
+            description: "Processing of DTC messages from the AWS Connected Vehicle Solution.",
+            sql: "SELECT * FROM 'connectedcar/dtc/#'",
+            actions: []
+        }
+    }
 };
 
-new IotToLambdaToDynamoDB(this, 'test-iot-lambda-dynamodb-stack', constructProps);
+new IotToLambdaToDynamoDB(this, 'test-iot-lambda-dynamodb-stack', props);
+
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_iot_lambda_dynamodb import IotToLambdaToDynamoDB
-from aws_cdk import (
-    aws_iot as iot,
-    aws_lambda as _lambda,
-    Stack
-)
-from constructs import Construct
-
-IotToLambdaToDynamoDB(self, 'test-iot-lambda-dynamodb-stack',
-            lambda_function_props=_lambda.FunctionProps(
-                code=_lambda.Code.from_asset('lambda'),
-                runtime=_lambda.Runtime.PYTHON_3_9,
-                handler='index.handler'
-            ),
-            iot_topic_rule_props=iot.CfnTopicRuleProps(
-                topic_rule_payload=iot.CfnTopicRule.TopicRulePayloadProperty(
-                    rule_disabled=False,
-                    description="Processing of DTC messages from the AWS Connected Vehicle Solution.",
-                    sql="SELECT * FROM 'connectedcar/dtc/#'",
-                    actions=[]
-                )
-            ))
+```text
+new IotToLambdaToDynamoDB(scope: Construct, id: string, props: IotToLambdaToDynamoDBProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-import java.util.List;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.lambda.*;
-import software.amazon.awscdk.services.lambda.Runtime;
-import software.amazon.awscdk.services.iot.*;
-import software.amazon.awscdk.services.iot.CfnTopicRule.TopicRulePayloadProperty;
-import software.amazon.awsconstructs.services.iotlambdadynamodb.*;
-
-new IotToLambdaToDynamoDB(this, "test-iot-lambda-dynamodb-stack", new IotToLambdaToDynamoDBProps.Builder()
-        .lambdaFunctionProps(new FunctionProps.Builder()
-                .runtime(Runtime.NODEJS_14_X)
-                .code(Code.fromAsset("lambda"))
-                .handler("index.handler")
-                .build())
-        .iotTopicRuleProps(new CfnTopicRuleProps.Builder()
-                .topicRulePayload(new TopicRulePayloadProperty.Builder()
-                        .ruleDisabled(false)
-                        .description("Processing of DTC messages from the AWS Connected Vehicle Solution.")
-                        .sql("SELECT * FROM 'connectedcar/dtc/#'")
-                        .actions(List.of())
-                        .build())
-                .build())
-        .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`IotToLambdaToDynamoDBProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -165,7 +113,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -177,30 +125,28 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_dynamodb
 import aws_cdk.aws_iot
 import aws_cdk.aws_lambda
-import aws_cdk.core
+import constructs
 
 
 class IotToLambdaToDynamoDB(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-iot-lambda-dynamodb.IotToLambdaToDynamoDB",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -216,10 +162,6 @@ class IotToLambdaToDynamoDB(
         :since: 0.8.0
         :summary: Constructs a new instance of the IotToLambdaToDynamoDB class.
         '''
-        if __debug__:
-            type_hints = typing.get_type_hints(IotToLambdaToDynamoDB.__init__)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToLambdaToDynamoDBProps(
             iot_topic_rule_props=iot_topic_rule_props,
             dynamo_table_props=dynamo_table_props,
@@ -261,10 +203,10 @@ class IotToLambdaToDynamoDBProps:
     def __init__(
         self,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -282,13 +224,6 @@ class IotToLambdaToDynamoDBProps:
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
-        if __debug__:
-            type_hints = typing.get_type_hints(IotToLambdaToDynamoDBProps.__init__)
-            check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
-            check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
-            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
-            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
-            check_type(argname="argument table_permissions", value=table_permissions, expected_type=type_hints["table_permissions"])
         self._values: typing.Dict[str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
